==> thingsboard_pe_client-1.0.0.tar.gz: lib/src/model/converter_models.dart <==
import 'package:thingsboard_pe_client/src/model/entity_type_models.dart';

import 'package:thingsboard_pe_client/src/model/id/tenant_id.dart';

import 'event_models.dart';
import 'has_name.dart';
import 'id/converter_id.dart';
import 'additional_info_based.dart';
import 'tenant_entity.dart';

enum ConverterType {
  UPLINK,
  DOWNLINK
}

ConverterType converterTypeFromString(String value) {
  return ConverterType.values.firstWhere((e)=>e.toString().split('.')[1].toUpperCase()==value.toUpperCase());
}

extension ConverterTypeToString on ConverterType {
  String toShortString() {
    return toString().split('.').last;
  }
}
class Converter extends AdditionalInfoBased<ConverterId> implements HasName, TenantEntity {

  TenantId? tenantId;
  String name;
  ConverterType type;
  bool debugMode;
  Map<String, dynamic> configuration;

  Converter({required this.name, required this.type, this.debugMode = false, required this.configuration});

  Converter.fromJson(Map<String, dynamic> json):
        tenantId = TenantId.fromJson(json['tenantId']),
        name = json['name'],
        type = converterTypeFromString(json['type']),
        debugMode = json['debugMode'],
        configuration = json['configuration'],
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    var json = super.toJson();
    if (tenantId != null) {
      json['tenantId'] = tenantId!.toJson();
    }
    json['name'] = name;
    json['type'] = type.toShortString();
    json['debugMode'] = debugMode;
    json['configuration'] = configuration;
    return json;
  }

  @override
  String getName() {
    return name;
  }

  @override
  EntityType getEntityType() {
    return EntityType.CONVERTER;
  }

  @override
  TenantId? getTenantId() {
    return tenantId;
  }

  @override
  String toString() {
    return 'Converter{tenantId: $tenantId, name: $name, type: $type, debugMode: $debugMode, configuration: $configuration}';
  }
}

class TestUpLinkInputParams {

  Map<String, String> metadata;
  String payload;
  String decoder;

  TestUpLinkInputParams({required this.metadata, required this.payload, required this.decoder});

  Map<String, dynamic> toJson() => {
    'metadata': metadata,
    'payload': payload,
    'decoder': decoder
  };
}

class TestDownLinkInputParams {

  Map<String, String> metadata;
  String msg;
  String msgType;
  Map<String, String> integrationMetadata;
  String encoder;

  TestDownLinkInputParams({required this.metadata, required this.msg, required this.msgType, required this.integrationMetadata, required this.encoder});

  Map<String, dynamic> toJson() => {
    'metadata': metadata,
    'msg': msg,
    'msgType': msgType,
    'integrationMetadata': integrationMetadata,
    'encoder': encoder
  };
}

class TestConverterResult {
  String? output;
  String? error;

  TestConverterResult.fromJson(Map<String, dynamic> json):
        output = json['output'],
        error = json['error'];

  @override
  String toString() {
    return 'TestConverterResult{output: $output, error: $error}';
  }
}

class ConverterDebugInput {

  ContentType inContentType;
  String inContent;
  String inMetadata;
  String inMsgType;
  String inIntegrationMetadata;

  ConverterDebugInput.fromJson(Map<String, dynamic> json):
        inContentType = contentTypeFromString(json['inContentType']),
        inContent = json['inContent'],
        inMetadata = json['inMetadata'],
        inMsgType = json['inMsgType'],
        inIntegrationMetadata = json['inIntegrationMetadata'];

  @override
  String toString() {
    return 'ConverterDebugInput{inContentType: $inContentType, inContent: $inContent, inMetadata: $inMetadata, inMsgType: $inMsgType, inIntegrationMetadata: $inIntegrationMetadata}';
  }
}

==> thingsboard_pe_client-1.0.3.tar.gz: lib/src/model/converter_models.dart <==
import 'package:thingsboard_pe_client/src/model/entity_type_models.dart';

import 'package:thingsboard_pe_client/src/model/id/tenant_id.dart';

import 'event_models.dart';
import 'has_name.dart';
import 'id/converter_id.dart';
import 'additional_info_based.dart';
import 'tenant_entity.dart';

enum ConverterType { UPLINK, DOWNLINK }

ConverterType converterTypeFromString(String value) {
  return ConverterType.values.firstWhere(
      (e) => e.toString().split('.')[1].toUpperCase() == value.toUpperCase());
}

extension ConverterTypeToString on ConverterType {
  String toShortString() {
    return toString().split('.').last;
  }
}

class Converter extends AdditionalInfoBased<ConverterId>
    implements HasName, TenantEntity {
  TenantId? tenantId;
  String name;
  ConverterType type;
  bool debugMode;
  Map<String, dynamic> configuration;

  Converter(
      {required this.name,
      required this.type,
      this.debugMode = false,
      required this.configuration});

  Converter.fromJson(Map<String, dynamic> json)
      : tenantId = TenantId.fromJson(json['tenantId']),
        name = json['name'],
        type = converterTypeFromString(json['type']),
        debugMode = json['debugMode'],
        configuration = json['configuration'],
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    var json = super.toJson();
    if (tenantId != null) {
      json['tenantId'] = tenantId!.toJson();
    }
    json['name'] = name;
    json['type'] = type.toShortString();
    json['debugMode'] = debugMode;
    json['configuration'] = configuration;
    return json;
  }

  @override
  String getName() {
    return name;
  }

  @override
  EntityType getEntityType() {
    return EntityType.CONVERTER;
  }

  @override
  TenantId? getTenantId() {
    return tenantId;
  }

  @override
  String toString() {
    return 'Converter{tenantId: $tenantId, name: $name, type: $type, debugMode: $debugMode, configuration: $configuration}';
  }
}

class TestUpLinkInputParams {
  Map<String, String> metadata;
  String payload;
  String decoder;

  TestUpLinkInputParams(
      {required this.metadata, required this.payload, required this.decoder});

  Map<String, dynamic> toJson() =>
      {'metadata': metadata, 'payload': payload, 'decoder': decoder};
}

class TestDownLinkInputParams {
  Map<String, String> metadata;
  String msg;
  String msgType;
  Map<String, String> integrationMetadata;
  String encoder;

  TestDownLinkInputParams(
      {required this.metadata,
      required this.msg,
      required this.msgType,
      required this.integrationMetadata,
      required this.encoder});

  Map<String, dynamic> toJson() => {
        'metadata': metadata,
        'msg': msg,
        'msgType': msgType,
        'integrationMetadata': integrationMetadata,
        'encoder': encoder
      };
}

class TestConverterResult {
  String? output;
  String? error;

  TestConverterResult.fromJson(Map<String, dynamic> json)
      : output = json['output'],
        error = json['error'];

  @override
  String toString() {
    return 'TestConverterResult{output: $output, error: $error}';
  }
}

class ConverterDebugInput {
  ContentType inContentType;
  String inContent;
  String inMetadata;
  String inMsgType;
  String inIntegrationMetadata;

  ConverterDebugInput.fromJson(Map<String, dynamic> json)
      : inContentType = contentTypeFromString(json['inContentType']),
        inContent = json['inContent'],
        inMetadata = json['inMetadata'],
        inMsgType = json['inMsgType'],
        inIntegrationMetadata = json['inIntegrationMetadata'];

  @override
  String toString() {
    return 'ConverterDebugInput{inContentType: $inContentType, inContent: $inContent, inMetadata: $inMetadata, inMsgType: $inMsgType, inIntegrationMetadata: $inIntegrationMetadata}';
  }
}
